# Frequenz Weather API Client Release Notes

## Summary

<!-- Here goes a general summary of what this release is about -->

## Upgrading

* This includes a major upgrade of `numpy` to v2.

## New Features

* Add method to combine conversion from forecast to ndarray and resampling in one method.
* Add support for Python 3.12.

## Bug Fixes

<!-- Here goes notable bug fixes that are worth a special mention or explanation -->
